export class RuleList extends Array {
    constructor(input) {
        super();
        if (input) {
            this.push(...Array.from(input));
        }
    }
    insertBefore(rule, newRule) {
        const index = this.findIndex((r) => r.name === rule);
        if (index === -1) {
            throw new Error(`Rule ${rule} not found`);
        }
        this.splice(index, 0, newRule);
    }
    insertAfter(rule, newRule) {
        const index = this.findIndex((r) => r.name === rule);
        if (index === -1) {
            throw new Error(`Rule ${rule} not found`);
        }
        this.splice(index + 1, 0, newRule);
    }
    toRuleObject() {
        const result = {};
        this.forEach((rule) => {
            result[rule.name] = rule;
        });
        return result;
    }
    add(rule) {
        this.push(rule);
    }
    get(rule) {
        return this.find((r) => r.name === rule);
    }
    remove(rule) {
        const index = this.findIndex((r) => r.name === rule);
        if (index === -1) {
            throw new Error(`Rule ${rule} not found`);
        }
        this.splice(index, 1);
    }
    clone() {
        return new RuleList(this);
    }
}
